@@ -40,15 +40,14 @@ ResultData = R6Class("ResultData",
         self$data = star_init()
       } else {
         assert_names(names(data),
-          permutation.of = c("task", "learner", "learner_state", "resampling", "iteration", "prediction", "uhash"))
+          permutation.of = c("task", "learner", "learner_state", "resampling", "iteration", "param_values", "prediction", "uhash", "learner_hash"))
 
         if (nrow(data) == 0L) {
           self$data = star_init()
         } else {
-          fact = data[, c("uhash", "iteration", "learner_state", "prediction", "task", "learner", "resampling"),
+          fact = data[, c("uhash", "iteration", "learner_state", "prediction", "task", "learner", "resampling", "param_values", "learner_hash"),
             with = FALSE]
           set(fact, j = "task_hash", value = hashes(fact$task))
-          set(fact, j = "learner_hash", value = hashes(fact$learner))
           set(fact, j = "learner_phash", value = phashes(fact$learner))
           set(fact, j = "resampling_hash", value = hashes(fact$resampling))
 
@@ -59,12 +58,13 @@ ResultData = R6Class("ResultData",
             keyby = "learner_phash"]
           resamplings = fact[, list(resampling = .SD$resampling[1L]),
             keyby = "resampling_hash"]
-          learner_components = fact[, list(learner_param_vals = list(.SD$learner[[1L]]$param_set$values)),
+          learner_components = fact[, list(learner_param_vals = list(.SD$param_values[[1]])),
             keyby = "learner_hash"]
 
           set(fact, j = "task", value = NULL)
           set(fact, j = "learner", value = NULL)
           set(fact, j = "resampling", value = NULL)
+          set(fact, j = "param_values", value = NULL)
           setkeyv(fact, c("uhash", "iteration"))
 
           if (!store_backends) {
@@ -354,8 +354,8 @@ star_init = function() {
     learner_state = list(),
     prediction = list(),
 
-    task_hash = character(),
     learner_hash = character(),
+    task_hash = character(),
     learner_phash = character(),
     resampling_hash = character(),
 
